==> kleopatra_18.04.3.orig.tar.xz: kleopatra-18.04.3/src/commands/adduseridcommand.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    commands/adduseridcommand.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEOPATRA_COMMANDS_ADDUSERIDCOMMAND_H__
#define __KLEOPATRA_COMMANDS_ADDUSERIDCOMMAND_H__

#include <commands/command.h>

namespace Kleo
{
namespace Commands
{

class AddUserIDCommand : public Command
{
    Q_OBJECT
public:
    explicit AddUserIDCommand(QAbstractItemView *view, KeyListController *parent);
    explicit AddUserIDCommand(KeyListController *parent);
    explicit AddUserIDCommand(const GpgME::Key &key);
    ~AddUserIDCommand();

    /* reimp */ static Restrictions restrictions()
    {
        return OnlyOneKey | MustBeOpenPGP | NeedSecretKey;
    }

    void setName(const QString &name);
    const QString &name() const;

    void setEmail(const QString &email);
    const QString &email() const;

    void setComment(const QString &comment);
    const QString &comment() const;

private:
    void doStart() override;
    void doCancel() override;

private:
    class Private;
    inline Private *d_func();
    inline const Private *d_func() const;
    Q_PRIVATE_SLOT(d_func(), void slotResult(GpgME::Error))
    Q_PRIVATE_SLOT(d_func(), void slotDialogAccepted())
    Q_PRIVATE_SLOT(d_func(), void slotDialogRejected())
};

}
}

#endif // __KLEOPATRA_COMMANDS_ADDUSERIDCOMMAND_H__

==> kleopatra-18.07.80.tar.xz: kleopatra-18.07.80/src/commands/adduseridcommand.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    commands/adduseridcommand.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEOPATRA_COMMANDS_ADDUSERIDCOMMAND_H__
#define __KLEOPATRA_COMMANDS_ADDUSERIDCOMMAND_H__

#include <commands/command.h>

namespace Kleo
{
namespace Commands
{

class AddUserIDCommand : public Command
{
    Q_OBJECT
public:
    explicit AddUserIDCommand(QAbstractItemView *view, KeyListController *parent);
    explicit AddUserIDCommand(KeyListController *parent);
    explicit AddUserIDCommand(const GpgME::Key &key);
    ~AddUserIDCommand() override;

    /* reimp */ static Restrictions restrictions()
    {
        return OnlyOneKey | MustBeOpenPGP | NeedSecretKey;
    }

    void setName(const QString &name);
    const QString &name() const;

    void setEmail(const QString &email);
    const QString &email() const;

    void setComment(const QString &comment);
    const QString &comment() const;

private:
    void doStart() override;
    void doCancel() override;

private:
    class Private;
    inline Private *d_func();
    inline const Private *d_func() const;
    Q_PRIVATE_SLOT(d_func(), void slotResult(GpgME::Error))
    Q_PRIVATE_SLOT(d_func(), void slotDialogAccepted())
    Q_PRIVATE_SLOT(d_func(), void slotDialogRejected())
};

}
}

#endif // __KLEOPATRA_COMMANDS_ADDUSERIDCOMMAND_H__
